@@ -19,8 +19,8 @@ class UserView(ModelSQL, ModelView):
     user = fields.Many2One('res.user', 'User')
     view_model = fields.Many2One('ir.model', 'View Model')
     view = fields.Many2One('ir.ui.view', 'View')
-    act_window = fields.Many2One('ir.action.act_window', 'Action')
     global_available = fields.Boolean('Available to all users')
+    # compact = fields.Boolean('Compact List')
     list_view_style = fields.Selection([
         ('', ''),
         ('comfortable', 'Comfortable'),
@@ -34,7 +34,6 @@ class UserView(ModelSQL, ModelView):
     field_model = fields.Many2One('ir.model', 'Field Model')
     user_view_fields = fields.One2Many(
         'user.view.field', 'user_view', 'Fields')
-    records_qty = fields.Integer('Records Quantity')
 
     @classmethod
     def __setup__(cls):
@@ -68,28 +67,15 @@ class UserView(ModelSQL, ModelView):
         return res
 
     @classmethod
-    def user_views_get(cls, user_id=None, view_id=None, field=False,
-            act_window=False):
+    def user_views_get(cls, user_id=None, view_id=None, field=False):
         '''
         Return list of user views.
         '''
-        print("GETTING USER VIE<ws")
         res = []
         domain = []
         pool = Pool()
         View = pool.get('user.view')
-        if act_window is not False:
-            if not user_id:
-                return res
-            domain = [
-                'OR',
-                [('user', '=', user_id), ('act_window', '=', act_window)],
-                [
-                    ('global_available', '=', True),
-                    ('act_window', '=', act_window)
-                ],
-                ]
-        elif field is False:
+        if field is False:
             if not user_id or not view_id:
                 return res
             domain = [
@@ -137,7 +123,6 @@ class UserView(ModelSQL, ModelView):
                     'order': view.order,
                     'global_available': view.global_available,
                     'field_name': view.field_name,
-                    'records_qty':view.records_qty or False,
                     'model': view.view_model.model,
                     } for view in views]
 
@@ -221,12 +206,6 @@ class UserView(ModelSQL, ModelView):
                 ('view', '=', view.view.id),
                 ('default', '=', True),
                 ]
-        elif view.act_window is not None:
-            domain = [
-                ('user', '=', user_id),
-                ('act_window', '=', view.act_window.id),
-                ('default', '=', True),
-                ]
         else:
             domain = [
                 ('user', '=', user_id),
@@ -245,7 +224,6 @@ class UserView(ModelSQL, ModelView):
             view.default = True
             view.save()
 
-    # TODO: Refactor
     @classmethod
     def user_view_set(cls, view_data={}):
         pool = Pool()
@@ -254,28 +232,26 @@ class UserView(ModelSQL, ModelView):
         Model = pool.get('ir.model')
         TrytonView = pool.get('ir.ui.view')
         TrytonField = pool.get('ir.model.field')
-        TrytonAction = pool.get('ir.action.act_window')
 
         if view_data['id'] > 0:
             view = View(view_data['id'])
         else:
             view = View()
 
-        
         view.name = view_data['name']
+
         view.order = view_data['order'] or None
         view.list_view_style = view_data['list_view_style'] or ''
         view.current_search = view_data['search'] or None
         view.user = view_data['user']
         view.global_available = view_data['global_available']
-        view.records_qty = view_data['records_qty']
 
         if view_data['view_id'] is not False:
             view.view = view_data['view_id']
             tview = TrytonView(view_data['view_id'])
             view.view_model = Model.search([('model', '=', tview.model)])[0].id
 
-        elif 'field_data' in view_data:
+        elif view_data['field_data']:
             f_data = view_data['field_data']
             view.field_name = f_data['name']
             view.view_model = Model.search(
@@ -283,12 +259,6 @@ class UserView(ModelSQL, ModelView):
             view.field_model = Model.search(
                 [('model', '=', f_data['model'])])[0].id
 
-        elif 'action' in view_data:
-            act_window = TrytonAction(view_data['action'])
-            view.act_window = act_window
-            view.view_model = Model.search(
-                [('model', '=', act_window.res_model)])[0].id
-
         def getField(field_data):
             f_id = field_data.get('id', -1)
             # check if the field and view exist
